summaryrefslogtreecommitdiff
path: root/src/lib/encoder.h
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2014-05-19 11:05:10 +0100
committerCarl Hetherington <cth@carlh.net>2014-05-19 11:05:10 +0100
commit9e758fddfb8bbadb1fc84e393daa815445d5e9d5 (patch)
tree291005ebf01a66f07ab05b09e72f634ddd1ac45a /src/lib/encoder.h
parent362ed9ee4f73bee21b3ef8d3b449bb8e8877f501 (diff)
parent69c08e8bbd5028a65cbddd2aa5f10632bd059191 (diff)
Merge delay-decode-take2 branch into master.
Diffstat (limited to 'src/lib/encoder.h')
-rw-r--r--src/lib/encoder.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/lib/encoder.h b/src/lib/encoder.h
index e0ee2d414..a8ee220aa 100644
--- a/src/lib/encoder.h
+++ b/src/lib/encoder.h
@@ -1,5 +1,5 @@
/*
- Copyright (C) 2012 Carl Hetherington <cth@carlh.net>
+ Copyright (C) 2012-2014 Carl Hetherington <cth@carlh.net>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ class EncodedData;
class Writer;
class Job;
class ServerFinder;
-class PlayerImage;
+class PlayerVideoFrame;
/** @class Encoder
* @brief Encoder to J2K and WAV for DCP.
@@ -67,10 +67,10 @@ public:
void process_begin ();
/** Call with a frame of video.
* @param i Video frame image.
* @param same true if i is the same as the last time we were called.
*/
- void process_video (boost::shared_ptr<PlayerImage> i, Eyes eyes, ColourConversion, bool same);
+ void process_video (boost::shared_ptr<PlayerVideoFrame> pvf, bool same);
/** Call with some audio data */
void process_audio (boost::shared_ptr<const AudioBuffers>);
@@ -67,10 +67,10 @@ public:
void process_begin ();
/** Call with a frame of video.
- * @param i Video frame image.
- * @param same true if i is the same as the last time we were called.
+ * @param pvf Video frame image.
+ * @param same true if pvf is the same as the last time we were called.
*/